# the platform url
hostname = 'http://hmgr.sec.lit.edu.cn/wms'

# the main api
endpoints = {
    'login': hostname + '/healthyLogin',
    'lastRecord': hostname + '/lastHealthyRecord',
    'firstRecord': hostname + '/addHealthyRecord',
    'secondRecord': hostname + '/addTwoHealthyRecord',
    'thirdRecord': hostname + '/addThreeHealthyRecord',
    'getInstructor': hostname + '/getInstructor',
    'getFamilys': hostname + '/familys/personal',
    'getTrips': hostname + '/trips/personal',
    'getImportantCity': hostname + '/teamImportantCity',
    'queryRecord': hostname + '/healthyRecordByUser'
}

# healthyRecordId=9037871&temperature=36.3&temperatureNormal=0



# sha256 for password
import hashlib
import datetime
import gb2260
import random


def get_sha256(password: str):
    str = hashlib.sha256(password.encode('utf-8')).hexdigest()
    return str

def get_today_time():
    return str(datetime.date.today())

# def get_now_timestamp():
#     return int(time.time())


# def datetime_timestamp(dt):
#     time.strptime(dt, '%Y-%m-%d %H:%M:%S')
#     ## time.struct_time(tm_year=2012, tm_mon=3, tm_mday=28, tm_hour=6, tm_min=53, tm_sec=40, tm_wday=2, tm_yday=88, tm_isdst=-1)
#     ts = time.mktime(time.strptime(dt, '%Y-%m-%d %H:%M:%S'))
#     return int(ts)

def cl_build(current_district):
    """ use gb2260 to build a CurrentLocation """
    div_result = []
    try:
        division = gb2260.get(current_district)
        for current in division.stack():
            temp = str(u'{0}'.format(current.name))
            div_result.append(temp)
            # use "-" to split str
        return("-".join(str(i) for i in div_result))
    except:
        return None

def current_location(currentDistrict, currentCity):
    """ is not grace :( """
    cl = cl_build(currentDistrict)
    if cl == None:
        cl = cl_build(currentCity)
    if cl == None:
        return None
    return cl

def random_temp():
    """ build a random temp """
    return round(random.uniform(36.0, 37.2), 2)



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
import requests
import json

from litncov import endpoints
from litncov import util


class litUesr:
    """lit uesr object"""

    def __init__(self, username: str, password: str):
        self.username = username
        self.password = util.get_sha256(password)

        self.__headers = {
            'Connection': 'keep-alive',
            'Content-Type': 'application/json'
        }

        try:
            # login the acconut
            self.info = self.__login()['data']
        except:
            self.info = None

        try:
            self.__headers['token'] = self.info['token']
            self.is_logged = True
        except:
            self.is_logged = False

    def __login(self):
        data = {
            'cardNo': self.username,
            'password': self.password
        }

        # login func
        try:
            response = requests.post(
                url=endpoints['login'], data=json.dumps(data), headers=self.__headers)
        except:
            return None

        res = response.json()

        return res

    def get_last_record(self):
        data = {
            'teamId': self.info['teamId'],
            'userId': self.info['userId']
        }

        try:
            response = requests.get(
                url=endpoints['lastRecord'], params=data, headers=self.__headers)
        except:
            return None

        res = response.json()

        return res
    
    def is_record_today(self, rtime = 1):
        try:
            # get the last record info
            last_record = self.get_last_record()['data']
        except:
            return None
        
        if last_record['createTime'][0:10] == util.get_today_time():
            if rtime == 1:
                return True
            elif (rtime == 2) & (last_record['createTime'] != ''):
                return True
            elif (rtime == 3) & (last_record['createTime'] != ''):
                return True
        else:
            return False
        
    def get_instructor(self):
        data = {
            'teamId': self.info['teamId'],
            'organizationName': self.info['organizationName'],
            'userOrganizationId': self.info['userOrganizationId']
        }

        try:
            response = requests.get(
                url=endpoints['getInstructor'], params=data, headers=self.__headers)
        except:
            return None

        res = response.json()

        return res

    def get_familys(self):
        data = {
            'userId': self.info['userId'],
        }

        try:
            response = requests.get(
                url=endpoints['getFamilys'], params=data, headers=self.__headers)
        except:
            return None

        res = response.json()

        return res

    def get_important_city(self):
        try:
            response = requests.get(
                url=endpoints['getImportantCity'], headers=self.__headers)
        except:
            return None

        res = response.json()
        return res

    def get_trips(self):
        data = {
            'userId': self.info['userId'],
            'teamId': self.info['teamId'],
        }

        try:
            response = requests.get(
                url=endpoints['getTrips'], params=data, headers=self.__headers)
        except:
            return None

        res = response.json()

        return res

    def query_record(self, st=util.get_today_time, et=util.get_today_time):
        data = {
            'pageNum': 1,
            'pageSize': 20,
            'userId': self.info['userId'],
            'teamId': self.info['teamId'],
            'startTime': st,
            'endTime': et
        }

        try:
            response = requests.get(
                url=endpoints['queryRecord'], params=data, headers=self.__headers)
        except:
            return None
        
        res = response.json()

        return res


    def first_record(self, mode='last', rtimes=1, temperature=36.1, temperatureTwo=36.2, temperatureThree=36.3):
        """
        the 'normal' will not record the temperatureTwo and temperatureThree values from last record
        and you can use the 'manual' for use your values, 'random' use random values
        """

        # get the last record info
        last_record = self.get_last_record()['data']

        data = {
            'mobile': self.info['mobile'],
            'nativePlaceProvince': self.info['nativePlaceProvince'],
            'nativePlaceCity': self.info['nativePlaceCity'],
            'nativePlaceDistrict': self.info['nativePlaceDistrict'],
            'nativePlaceAddress': self.info['nativePlaceAddress'],
            'localAddress': self.info['localAddress'],
            'currentProvince': last_record['currentProvince'],
            'currentCity': last_record['currentCity'],
            'currentDistrict': last_record['currentDistrict'],
            'currentLocation': util.current_location(last_record['currentDistrict'], last_record['currentCity']),
            'currentAddress': last_record['currentAddress'],
            'villageIsCase': last_record['villageIsCase'],
            'caseAddress': last_record['caseAddress'],
            'peerIsCase': last_record['peerIsCase'],
            'peerAddress': last_record['peerAddress'],
            'isInTeamCity': last_record['isInTeamCity'],
            'temperatureNormal': last_record['temperatureNormal'],
            'temperature': last_record['temperature'],
            'selfHealthy': last_record['selfHealthy'],
            'selfHealthyInfo': last_record['selfHealthyInfo'],
            'selfHealthyTime': last_record['selfHealthyTime'],
            'friendHealthy': last_record['friendHealthy'],
            'isolation': last_record['isolation'],
            'currentStatus': last_record['currentStatus'],
            'diagnosisTime': last_record['diagnosisTime'],
            'treatmentHospitalAddress': last_record['treatmentHospitalAddress'],
            'cureTime': last_record['cureTime'],
            'travelPatient': last_record['travelPatient'],
            'goHuBeiCity': last_record['goHuBeiCity'],
            'goHuBeiTime': last_record['goHuBeiTime'],
            'contactPatient': last_record['contactPatient'],
            'contactTime': last_record['contactTime'],
            'contactProvince': last_record['contactProvince'],
            'contactCity': last_record['contactCity'],
            'contactDistrict': last_record['contactDistrict'],
            'contactLocation': '',  # temporary emtpy
            'contactAddress': last_record['contactAddress'],
            'isAbroad':  last_record['isAbroad'],
            'abroadInfo': last_record['abroadInfo'],
            'seekMedical': last_record['seekMedical'],
            'seekMedicalInfo': last_record['seekMedicalInfo'],
            'exceptionalCase': last_record['exceptionalCase'],
            'exceptionalCaseInfo': last_record['exceptionalCaseInfo'],
            'isTrip':  last_record['isAbroad'],  # temporary use
            'userId': self.info['userId'],
            'teamId': self.info['teamId'],
            'healthyStatus': last_record['healthyStatus'],
            'temperatureTwo': '',
            'temperatureThree': '',
            'reportDate': util.get_today_time()
        }

        if mode == 'last':
            if rtimes >= 2:
                data['temperatureTwo'] = last_record['temperatureTwo']
            if rtimes == 3:
                data['temperatureThree'] = last_record['temperatureThree']
        elif mode == 'random':
            data['temperature'] = util.random_temp()
            if rtimes >= 2:
                data['temperatureTwo'] = util.random_temp()
            if rtimes == 3:
                data['temperatureThree'] = util.random_temp()
        elif mode == 'manual':
            data['temperature'] = temperature
            if rtimes >= 2:
                data['temperatureTwo'] = temperatureTwo
            if rtimes == 3:
                data['temperatureThree'] = temperatureThree
        else:
            return None

        try:
            response = requests.post(
                url=endpoints['firstRecord'], data=json.dumps(data), headers=self.__headers)
            # res['data']['temperature'] = data['temperature']
            # res['data']['temperatureTwo'] = data['temperatureTwo']
            # res['data']['temperatureThree'] = data['temperatureThree']
            # {"success":true,"code":200,"msg":"请求成功","data":""}
        except:
            return None

        res = response.json()

        res['data'] = {'temperature': data['temperature']}
        if rtimes >= 2:
            res['data']['temperatureTwo'] = data['temperatureTwo']
        if rtimes == 3:
            res['data']['temperatureThree'] = data['temperatureThree']

        return res

    def second_record(self, mode='last', temperature=36.6):
        """
        mode: 'last', 'random' and 'manual'
        """

        # get the last record info
        last_record = self.get_last_record()['data']

        data = {
            'healthyRecordId': last_record['id'],
            'temperature': last_record['temperatureTwo'],
            'temperatureNormal': last_record['temperatureNormal']
        }

        if mode == 'last':
            pass
        elif mode == 'random':
            data['temperature'] = util.random_temp()
        elif mode == 'manual':
            data['temperature'] = temperature
        else:
            return None

        try:
            response = requests.put(
                url=endpoints['secondRecord'], params=data, headers=self.__headers)
        except:
            return None

        res = response.json()
        res['data'] = {'temperature': data['temperature']}

        return res

    def third_record(self, mode='last', temperature=36.6):
        """
        mode: 'last', 'random' and 'manual'
        """

        # get the last record info
        last_record = self.get_last_record()['data']

        data = {
            'healthyRecordId': last_record['id'],
            'temperature': last_record['temperatureThree'],
            'temperatureNormal': last_record['temperatureNormal']
        }

        if mode == 'last':
            pass
        elif mode == 'random':
            data['temperature'] = util.random_temp()
        elif mode == 'manual':
            data['temperature'] = temperature
        else:
            return None

        try:
            response = requests.put(
                url=endpoints['thirdRecord'], params=data, headers=self.__headers)
        except:
            return None

        res = response.json()
        res['data'] = {'temperature': data['temperature']}

        return res




from os import path as os_path
from setuptools import setup

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(name='litncov',
      version='0.1.6',
      description='A ncov report library and tool for LIT(Luoyang Institute of Science and Technology)',
      long_description=long_description,
      long_description_content_type="text/markdown",
      url='http://github.com/icepie/lit-ncov-report',
      author='Tea',
      author_email='icepie.dev@gmail.com',
      license='MIT',
      packages=['litncov'],
      install_requires=[
          'click',
          'requests',
          'gb2260'
      ],
      python_requires='>=3.6',
      entry_points={
          'console_scripts': [
              'litncov = litncov.main:main',
          ],
      }
      )
